Index: pkg/dartino_compiler/lib/src/hub/exit_codes.dart |
diff --git a/pkg/fletchc/lib/src/hub/exit_codes.dart b/pkg/dartino_compiler/lib/src/hub/exit_codes.dart |
similarity index 89% |
rename from pkg/fletchc/lib/src/hub/exit_codes.dart |
rename to pkg/dartino_compiler/lib/src/hub/exit_codes.dart |
index 765714dca36199babafeace5c57bc213c2900818..c6b203f3b2b31cda044d8597afaa89e0f2ed7173 100644 |
--- a/pkg/fletchc/lib/src/hub/exit_codes.dart |
+++ b/pkg/dartino_compiler/lib/src/hub/exit_codes.dart |
@@ -5,7 +5,7 @@ |
/// Exit codes recognized by our test infrastructure. This file is shared with |
/// our test infrastructure and should be kept simple and only contain |
/// int-valued top-level compile-time constants. |
-library fletchc.exit_codes; |
+library dartino_compiler.exit_codes; |
/// Exit code to use when the compiler crashed. This is recognized by our test |
/// runner (test.dart) as status `Crash`. |
@@ -15,12 +15,12 @@ const COMPILER_EXITCODE_CONNECTION_ERROR = 252; |
/// runner (test.dart) as status `Crash`. |
const COMPILER_EXITCODE_CRASH = 253; |
/// Exit code to use when the program running on the Fletch VM encounters a |
/// compile-time error. This is recognized by our test runner (test.dart) as |
/// status `CompileTimeError`. |
const DART_VM_EXITCODE_COMPILE_TIME_ERROR = 254; |
/// Exit code to use when the program running on the Fletch VM throws an |
/// uncaught exception. This is recognized by out test runner (test.dart) as |
/// status `RuntimeError`. |
const DART_VM_EXITCODE_UNCAUGHT_EXCEPTION = 255; |
@@ -15,12 +15,12 @@ const COMPILER_EXITCODE_CONNECTION_ERROR = 252; |
/// runner (test.dart) as status `Crash`. |
const COMPILER_EXITCODE_CRASH = 253; |
-/// Exit code to use when the program running on the Fletch VM encounters a |
+/// Exit code to use when the program running on the Dartino VM encounters a |
/// compile-time error. This is recognized by our test runner (test.dart) as |
/// status `CompileTimeError`. |
@@ -15,12 +15,12 @@ const COMPILER_EXITCODE_CONNECTION_ERROR = 252; |
/// status `CompileTimeError`. |
const DART_VM_EXITCODE_COMPILE_TIME_ERROR = 254; |
-/// Exit code to use when the program running on the Fletch VM throws an |
+/// Exit code to use when the program running on the Dartino VM throws an |
/// uncaught exception. This is recognized by out test runner (test.dart) as |
/// status `RuntimeError`. |